@@ -19,14 +19,12 @@
 #' ces(), gum(), ssarima() and sma() functions.
 #' \item \link[smooth]{cma} - Centered Moving Average. This is for smoothing time series,
 #' not for forecasting.
-#' \item \link[smooth]{ves} - Vector Exponential Smoothing.
 #' \item \link[smooth]{sim.es} - simulate time series using ETS as a model.
 #' \item \link[smooth]{sim.ces} - simulate time series using CES as a model.
 #' \item \link[smooth]{sim.ssarima} - simulate time series using SARIMA as a model.
 #' \item \link[smooth]{sim.gum} - simulate time series using GUM as a model.
 #' \item \link[smooth]{sim.sma} - simulate time series using SMA.
 #' \item \link[smooth]{oes} - occurrence part of the intermittent state space model.
-#' \item \link[smooth]{viss} - Does the same as iss, but for the multivariate models.
 #' }
 #' There are also several methods implemented in the package for the classes
 #' "smooth" and "smooth.sim":
@@ -53,7 +51,7 @@
 #' @author Ivan Svetunkov
 #'
 #' Maintainer: Ivan Svetunkov <ivan@svetunkov.ru>
-#' @seealso \code{\link[forecast:forecast]{forecast}, \link[smooth]{es},
+#' @seealso \code{\link[greybox]{forecast}, \link[smooth]{es},
 #' \link[smooth]{ssarima}, \link[smooth]{ces}, \link[smooth]{gum}}
 #'
 #' @template ssGeneralRef
@@ -76,12 +74,34 @@
 #' @import zoo Rcpp
 #' @importFrom nloptr nloptr
 #' @importFrom graphics abline layout legend lines par points polygon
-#' @importFrom stats AIC BIC cov dbeta decompose deltat end frequency is.ts median coef optimize nlminb cor qnorm qt qlnorm quantile rbinom rlnorm rnorm rt runif start time ts var simulate lm as.formula residuals plnorm pnorm
+#' @importFrom stats AIC BIC cov decompose median coef optimize nlminb cor var simulate lm as.formula residuals
+#' @importFrom stats dbeta qnorm qt qlnorm quantile rbinom rlnorm rnorm rt runif plnorm pnorm
+#' @importFrom stats deltat end frequency is.ts start time ts
 #' @importFrom utils packageVersion
 #' @importFrom greybox xregExpander stepwise qs qlaplace ps plaplace ds dlaplace graphmaker measures hm
-#' @importFrom forecast is.ets
 #' @useDynLib smooth
 NULL
 
+#' Vector exponential smoothing
+#'
+#' VES and related functions. These have been moved to legion package starting from smooth v3.1.0.
+#'
+#' @param ... parameters of the model
+#'
+#' @rdname ves
+#' @export
+ves <- function(...){
+    .Defunct("ves", package = "legion", "The function ves() is no longer available in smooth. It has been moved to the package legion: https://github.com/config-i1/legion")
+}
 
+#' @rdname ves
+#' @export
+viss <- function(...){
+    .Defunct("oves", package = "legion", "The function oves() is no longer available in smooth. It has been moved to the package legion: https://github.com/config-i1/legion")
+}
 
+#' @rdname ves
+#' @export
+sim.ves <- function(...){
+    .Defunct("sim.ves", package = "legion", "The function viss() is no longer available in smooth. It has been moved to the package legion: https://github.com/config-i1/legion")
+}
